[PATCH] D24539: [zorg] Don't exclude compiler-rt runtimes from build.py artifacts

Phabricator via llvm-commits llvm-commits at lists.llvm.org
Wed Sep 14 10:52:45 PDT 2016


This revision was automatically updated to reflect the committed changes.
Closed by commit rL281511: [zorg] Don't exclude compiler-rt runtimes from build.py artifacts (authored by vedantk).

Changed prior to commit:
  https://reviews.llvm.org/D24539?vs=71283&id=71395#toc

Repository:
  rL LLVM

https://reviews.llvm.org/D24539

Files:
  zorg/trunk/zorg/jenkins/build.py

Index: zorg/trunk/zorg/jenkins/build.py
===================================================================
--- zorg/trunk/zorg/jenkins/build.py
+++ zorg/trunk/zorg/jenkins/build.py
@@ -672,8 +672,10 @@
         prop_fd.write("LLVM_REV={}\n".format(conf.svn_rev))
         prop_fd.write("ARTIFACT={}\n".format(new_url))
 
-    # The .a's are big and we don't need them later. Drop them.
-    tar = ["tar", "zcvf", "../" + artifact_name, '--exclude=*.a',  "."]
+    # The .a's are big and we don't need them later. Drop the LLVM and clang
+    # libraries, but keep the libraries from compiler-rt.
+    tar = ["tar", "zcvf", "../" + artifact_name, "--exclude=*libLLVM*.a",
+           "--exclude=*libclang[A-Z]*.a", "."]
 
     run_cmd(conf.installdir(), tar)
 


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D24539.71395.patch
Type: text/x-patch
Size: 761 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20160914/080ebd5c/attachment.bin>


More information about the llvm-commits mailing list